﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Media;
using System.Windows.Shapes;
using Syncfusion.Windows.Chart;
using Syncfusion.Windows.SampleLayout;
using sfchart= Syncfusion.UI.Xaml.Charts;

namespace FastChartTypesDemo
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : SampleLayoutWindow
    {
        DataGenerator _viewModel;

        public Window1()
        {
            InitializeComponent();

            _viewModel = new DataGenerator();
        }

        private void btnRefresh_Click(object sender, RoutedEventArgs e)
        {
            PaintGraph();
        }

        private void PaintGraph()
        {
            if (mainChart != null && mainChart.Series.Count > 0)
            {
                mainChart.Series.Clear();
            }

            mainChart.BeginInit();

            sfchart.FastLineSeries series = null;

            for (int i = 0; i < 6; i++)
            {
                series = new sfchart.FastLineSeries();
                series.BeginInit();
                series.XBindingPath = "Date";
                series.YBindingPath = "Value";
                series.ItemsSource = _viewModel.GenerateData();
                series.StrokeThickness = 5;
                series.Label = "Graph" + i.ToString();

                series.EndInit();

                mainChart.Series.Add(series);
            }

            mainChart.EndInit();
        }

        private void btnRemove_Click(object sender, RoutedEventArgs e)
        {
            if (mainGrid.Children.Contains(mainChart))
            {
                mainChart.Series.Clear();
                mainGrid.Children.Remove(mainChart);
                btnRefresh.IsEnabled = false;
                btnRemove.IsEnabled = false;
            }
        }

        private void top_Click(object sender, RoutedEventArgs e)
        {
            var header = (e.OriginalSource as MenuItem).Header.ToString();
            switch(header)
            {
                case "Top":
                    (mainChart.Legend as sfchart.ChartLegend).DockPosition = sfchart.ChartDock.Top;
                    break;
                case "Bottom":
                    (mainChart.Legend as sfchart.ChartLegend).DockPosition = sfchart.ChartDock.Bottom;
                    break;
                case "Left":
                    (mainChart.Legend as sfchart.ChartLegend).DockPosition = sfchart.ChartDock.Left;
                    break;
                case "Right":
                    (mainChart.Legend as sfchart.ChartLegend).DockPosition = sfchart.ChartDock.Right;
                    break;
                case "Visible":
                    (mainChart.Legend as sfchart.ChartLegend).CheckBoxVisibility = Visibility.Visible;
                    break;
                case "Collapsed":
                    (mainChart.Legend as sfchart.ChartLegend).CheckBoxVisibility = Visibility.Collapsed;
                    break;
                case "Metro":
                    mainChart.Palette = sfchart.ChartColorPalette.Metro;
                    break;
                case "AutumnBrights":
                    mainChart.Palette = sfchart.ChartColorPalette.AutumnBrights;
                    break;
                case "FloraHues":
                    mainChart.Palette = sfchart.ChartColorPalette.FloraHues;
                    break;
                case "PineApple":
                    mainChart.Palette = sfchart.ChartColorPalette.Pineapple;
                    break;
                case "Elite":
                    mainChart.Palette = sfchart.ChartColorPalette.Elite;
                    break;
                case "SandyBeach":
                    mainChart.Palette = sfchart.ChartColorPalette.SandyBeach;
                    break;
                case "LightCandy":
                    mainChart.Palette = sfchart.ChartColorPalette.LightCandy;
                    break;
                case "Print":
                    mainChart.Print();
                    break;
                case "Save":
                    mainChart.Save("chart.png");
                    break;
                case "CrossHairBehavior":
                    {
                        mainChart.Behaviors.Add(new sfchart.ChartCrossHairBehavior());
                        mainChart.PrimaryAxis.ShowTrackBallInfo = true;
                        mainChart.SecondaryAxis.ShowTrackBallInfo = true;
                    }               
                    break;
                default:
                    break;
            }
        }
    }
}





